==> zscaler_sdk_python-1.5.2.tar.gz: zscaler_sdk_python-1.5.2/zscaler/zpa/models/certificates.py <==
"""
Copyright (c) 2023, Zscaler Inc.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted, provided that the above
copyright notice and this permission notice appear in all copies.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
"""

from zscaler.oneapi_object import ZscalerObject
from zscaler.oneapi_collection import ZscalerCollection


class Certificate(ZscalerObject):
    def __init__(self, config=None):
        """
        Initialize the Certificate model based on API response.
        Args:
            config (dict): A dictionary representing the certificate configuration.
        """
        super().__init__(config)
        if config:
            self.id = config["id"] if "id" in config else None
            self.modified_time = config["modifiedTime"] if "modifiedTime" in config else None
            self.creation_time = config["creationTime"] if "creationTime" in config else None
            self.modified_by = config["modifiedBy"] if "modifiedBy" in config else None
            self.name = config["name"] if "name" in config else None
            self.description = config["description"] if "description" in config else None
            self.cname = config["cName"] if "cName" in config else None
            self.valid_from = config["validFromInEpochSec"] if "validFromInEpochSec" in config else None
            self.valid_to = config["validToInEpochSec"] if "validToInEpochSec" in config else None
            self.certificate = config["certificate"] if "certificate" in config else None
            self.issued_to = config["issuedTo"] if "issuedTo" in config else None
            self.issued_by = config["issuedBy"] if "issuedBy" in config else None
            self.serial_no = config["serialNo"] if "serialNo" in config else None
            self.public_key = config["publicKey"] if "publicKey" in config else None

            self.status = config["status"] if "status" in config else None
            self.microtenant_name = config["microtenantName"] if "microtenantName" in config else None
            self.microtenant_id = config["microtenantId"] if "microtenantId" in config else None

            self.san = ZscalerCollection.form_list(config["san"] if "san" in config else [], str)
        else:
            self.id = None
            self.modified_time = None
            self.creation_time = None
            self.modified_by = None
            self.name = None
            self.description = None
            self.cname = None
            self.valid_from = None
            self.valid_to = None
            self.certificate = None
            self.issued_to = None
            self.issued_by = None
            self.serial_no = None
            self.public_key = None
            self.status = None
            self.san = ZscalerCollection.form_list([], str)
            self.microtenant_name = None
            self.microtenant_id = None

    def request_format(self):
        """
        Formats the Certificate data into a dictionary suitable for API requests.
        """
        parent_req_format = super().request_format()
        current_obj_format = {
            "id": self.id,
            "name": self.name,
            "description": self.description,
            "cName": self.cname,
            "validFromInEpochSec": self.valid_from,
            "validToInEpochSec": self.valid_to,
            "certificate": self.certificate,
            "issuedTo": self.issued_to,
            "issuedBy": self.issued_by,
            "serialNo": self.serial_no,
            "publicKey": self.public_key,
            "status": self.status,
            "san": self.san,
            "microtenantName": self.microtenant_name,
            "microtenantId": self.microtenant_id,
        }
        parent_req_format.update(current_obj_format)
        return parent_req_format

==> zscaler_sdk_python-1.9.2.tar.gz: zscaler_sdk_python-1.9.2/zscaler/zpa/models/certificates.py <==
"""
Copyright (c) 2023, Zscaler Inc.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted, provided that the above
copyright notice and this permission notice appear in all copies.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
"""

from typing import Dict, List, Optional, Any, Union
from zscaler.oneapi_object import ZscalerObject
from zscaler.oneapi_collection import ZscalerCollection


class Certificate(ZscalerObject):
    def __init__(self, config: Optional[Dict[str, Any]] = None) -> None:
        """
        Initialize the Certificate model based on API response.
        Args:
            config (dict): A dictionary representing the certificate configuration.
        """
        super().__init__(config)
        if config:
            self.id = config["id"] if "id" in config else None
            self.modified_time = config["modifiedTime"] if "modifiedTime" in config else None
            self.creation_time = config["creationTime"] if "creationTime" in config else None
            self.modified_by = config["modifiedBy"] if "modifiedBy" in config else None
            self.name = config["name"] if "name" in config else None
            self.description = config["description"] if "description" in config else None
            self.cname = config["cName"] if "cName" in config else None
            self.valid_from = config["validFromInEpochSec"] if "validFromInEpochSec" in config else None
            self.valid_to = config["validToInEpochSec"] if "validToInEpochSec" in config else None
            self.certificate = config["certificate"] if "certificate" in config else None
            self.issued_to = config["issuedTo"] if "issuedTo" in config else None
            self.issued_by = config["issuedBy"] if "issuedBy" in config else None
            self.serial_no = config["serialNo"] if "serialNo" in config else None
            self.public_key = config["publicKey"] if "publicKey" in config else None

            self.status = config["status"] if "status" in config else None
            self.microtenant_name = config["microtenantName"] if "microtenantName" in config else None
            self.microtenant_id = config["microtenantId"] if "microtenantId" in config else None

            self.san = ZscalerCollection.form_list(config["san"] if "san" in config else [], str)
        else:
            self.id = None
            self.modified_time = None
            self.creation_time = None
            self.modified_by = None
            self.name = None
            self.description = None
            self.cname = None
            self.valid_from = None
            self.valid_to = None
            self.certificate = None
            self.issued_to = None
            self.issued_by = None
            self.serial_no = None
            self.public_key = None
            self.status = None
            self.san = ZscalerCollection.form_list([], str)
            self.microtenant_name = None
            self.microtenant_id = None

    def request_format(self) -> Dict[str, Any]:
        """
        Formats the Certificate data into a dictionary suitable for API requests.
        """
        parent_req_format = super().request_format()
        current_obj_format = {
            "id": self.id,
            "name": self.name,
            "description": self.description,
            "cName": self.cname,
            "validFromInEpochSec": self.valid_from,
            "validToInEpochSec": self.valid_to,
            "certificate": self.certificate,
            "issuedTo": self.issued_to,
            "issuedBy": self.issued_by,
            "serialNo": self.serial_no,
            "publicKey": self.public_key,
            "status": self.status,
            "san": self.san,
            "microtenantName": self.microtenant_name,
            "microtenantId": self.microtenant_id,
        }
        parent_req_format.update(current_obj_format)
        return parent_req_format
